@@ -2,12 +2,12 @@
 Collection of utilities, formerly in rsp_jupyter_utils.lab and
 rsp_jupyter_utils.helper
 """
-from .catalog import get_tap_service, get_catalog, retrieve_query
+from .catalog import get_catalog, get_tap_service, retrieve_query
 from .forwarder import Forwarder
 from .logging import IPythonHandler, forward_lsst_log
 from .utils import (
-    get_access_token,
     format_bytes,
+    get_access_token,
     get_digest,
     get_hostname,
     get_node,
